var _ogre_shader_ex_integrated_p_s_s_m3_8h =
[
    [ "SGX_LIB_INTEGRATEDPSSM", "group___r_t_shader.html#gaef923817b4e357235b862cbea0147e2b", null ],
    [ "SGX_FUNC_COMPUTE_SHADOW_COLOUR3", "group___r_t_shader.html#ga78adec906ae28462e707fce51123b007", null ],
    [ "SGX_FUNC_APPLYSHADOWFACTOR_DIFFUSE", "group___r_t_shader.html#ga8bc52c44d087e8e3fccfe6ac0f8228bc", null ]
];